Crate imghash

source ·

Modules

Structs

Enums

Traits

Functions

  • Calculate the average hash for an image at the specified path. Uses the default width and height of 8 x 8 pixels. If you want to use something else please directly use the AverageHasher struct.
  • Calculate the difference hash for an image at the specified path. Uses the default width and height of 8 x 8 pixels. If you want to use something else please directly use the DifferenceHasher struct.
  • Calculate the perceptual hash for an image at the specified path. Uses the default width and height of 8 x 8 pixels as well as the default factor of 4. If you want to use something else please directly use the PerceptualHasher struct.