Modules
Structs
Enums
Traits
- Trait for generating image hashes
Functions
- Calculate the average hash for an image at the specified path. Uses the default width and height of 8 x 8 pixels. If you want to use something else please directly use the
AverageHasherstruct. - Calculate the difference hash for an image at the specified path. Uses the default width and height of 8 x 8 pixels. If you want to use something else please directly use the
DifferenceHasherstruct. - Calculate the perceptual hash for an image at the specified path. Uses the default width and height of 8 x 8 pixels as well as the default factor of 4. If you want to use something else please directly use the
PerceptualHasherstruct.